==> currents-api-types-0.0.70.tgz: package/stripe/parsers.ts <==
import { z } from 'zod';
import {
  STRIPE_CONNECT_ACCOUNT_PREFIX,
  STRIPE_CONNECT_CLIENT_PREFIX,
  STRIPE_CONNECT_TRANSFER_PREFIX,
  STRIPE_CONNECT_TRANSFER_REVERSAL_PREFIX,
  STRIPE_CUSTOMER_PREFIX,
  STRIPE_INVOICE_PREFIX,
  STRIPE_PAYMENT_INTENT_PREFIX,
  STRIPE_PAYMENT_METHOD_PREFIX,
  STRIPE_PAYOUT_PREFIX,
  STRIPE_PRICE_PREFIX,
  STRIPE_PRODUCT_PREFIX,
  STRIPE_SUBSCRIPTION_PREFIX,
} from './constants';
import type {
  StripeConnectClientId,
  StripeConnectTransferId,
  StripeConnectTransferReversalId,
  StripeCustomerId,
  StripeInvoiceId,
  StripePaymentIntentId,
  StripePayinMethodId,
  StripeTransferId,
  StripePriceId,
  StripeProductId,
  StripeSubscriptionId,
} from './types';
import { getChannelIdFromPriceId } from './price.utils';
import { isChannelId } from '../channel/utils';
import { cast } from '../utils/types';
import { timestampParser } from '../parsers';

export const stripeProductIdParser = z
  .string()
  .startsWith(STRIPE_PRODUCT_PREFIX)
  .length(19)
  .transform(cast<StripeProductId>());
export const stripePaymentMethodIdParser = z
  .string()
  .startsWith(STRIPE_PAYMENT_METHOD_PREFIX)
  .transform(cast<StripePayinMethodId>());
export const stripeCustomerIdParser = z.string().startsWith(STRIPE_CUSTOMER_PREFIX).transform(cast<StripeCustomerId>());
export const stripeInvoiceIdParser = z.string().startsWith(STRIPE_INVOICE_PREFIX).transform(cast<StripeInvoiceId>());
export const stripePaymentIntentIdParser = z
  .string()
  .startsWith(STRIPE_PAYMENT_INTENT_PREFIX)
  .transform(cast<StripePaymentIntentId>());

export const stripePayoutIdParser = z.string().startsWith(STRIPE_PAYOUT_PREFIX).transform(cast<StripeTransferId>());
export const stripeSubscriptionIdParser = z
  .string()
  .startsWith(STRIPE_SUBSCRIPTION_PREFIX)
  .transform(cast<StripeSubscriptionId>());
export const stripePriceIdParser = z
  .string()
  .startsWith(STRIPE_PRICE_PREFIX)
  .superRefine((s, ctx) => {
    const channelId = getChannelIdFromPriceId(s as StripePriceId);
    if (!channelId || !isChannelId(channelId)) {
      ctx.addIssue({
        code: 'custom',
        message: "Can't find a valid channel id in provided price id",
      });
    }
  })
  .transform(cast<StripePriceId>());
export const stripeConnectAccountIdParser = z
  .string()
  .startsWith(STRIPE_CONNECT_ACCOUNT_PREFIX)
  .transform(cast<StripeConnectClientId>());

export const stripeConnectTransferIdParser = z
  .string()
  .startsWith(STRIPE_CONNECT_TRANSFER_PREFIX)
  .transform(cast<StripeConnectTransferId>());
export const stripeConnectTransferReversalIdParser = z
  .string()
  .startsWith(STRIPE_CONNECT_TRANSFER_REVERSAL_PREFIX)
  .transform(cast<StripeConnectTransferReversalId>());
export const stripeConnectClientIdParser = z
  .string()
  .startsWith(STRIPE_CONNECT_CLIENT_PREFIX)
  .transform(cast<StripeConnectClientId>());

export const stripeAddressParser = z.object({
  city: z.string().nullable(),
  country: z.string().nullable(),
  line1: z.string().nullable(),
  line2: z.string().nullable(),
  postal_code: z.string().nullable(),
  state: z.string().nullable(),
});

export const stripeCardBrandParser = z.string(); // enumeration but we don't care as much yet

// asserted in non-shared code
export const stripeCardFlatParser = z.object({
  brand: stripeCardBrandParser,
  last4: z.string().min(4).max(4),
});

// asserted in non-shared code
export const stripePaymentMethodFlatParser = z.object({
  id: stripePaymentMethodIdParser,
  object: z.literal('payment_method'),
  customer: stripeCustomerIdParser.nullable(),
  billing_details: z.object({
    address: stripeAddressParser.nullable(),
    email: z.string().nullable(),
    name: z.string().nullable(),
    phone: z.string().nullable(),
  }),
  created: timestampParser,
  metadata: z
    .object({
      /*freeform*/
    })
    .nullable(),
  card: stripeCardFlatParser.optional(),
});

==> currents-api-types-0.0.84.tgz: package/stripe/parsers.ts <==
import { z, ZodString } from 'zod';
import {
  STRIPE_CONNECT_ACCOUNT_PREFIX,
  STRIPE_CONNECT_CLIENT_PREFIX,
  STRIPE_CONNECT_TRANSFER_PREFIX,
  STRIPE_CONNECT_TRANSFER_REVERSAL_PREFIX,
  STRIPE_CUSTOMER_PREFIX,
  STRIPE_INVOICE_PREFIX,
  STRIPE_PAYMENT_INTENT_PREFIX,
  STRIPE_PAYMENT_METHOD_PREFIXES,
  STRIPE_PAYOUT_PREFIX,
  STRIPE_PRICE_PREFIX,
  STRIPE_PRODUCT_PREFIX,
  STRIPE_SUBSCRIPTION_PREFIX,
} from './constants';
import type {
  StripeConnectClientId,
  StripeConnectTransferId,
  StripeConnectTransferReversalId,
  StripeCustomerId,
  StripeInvoiceId,
  StripePaymentIntentId,
  StripePayinMethodId,
  StripeTransferId,
  StripePriceId,
  StripeProductId,
  StripeSubscriptionId,
} from './types';
import { getChannelIdFromPriceId } from './price.utils';
import { isChannelId } from '../channel/utils';
import { cast } from '../utils/types';
import { timestampParser } from '../parsers';

export const stripeProductIdParser = z
  .string()
  .startsWith(STRIPE_PRODUCT_PREFIX)
  .length(19)
  .transform(cast<StripeProductId>());
export const stripePaymentMethodIdParser = z
  .union(STRIPE_PAYMENT_METHOD_PREFIXES.map((p) => z.string().startsWith(p)) as [ZodString, ZodString, ...ZodString[]])
  .transform(cast<StripePayinMethodId>());
export const stripeCustomerIdParser = z.string().startsWith(STRIPE_CUSTOMER_PREFIX).transform(cast<StripeCustomerId>());
export const stripeInvoiceIdParser = z.string().startsWith(STRIPE_INVOICE_PREFIX).transform(cast<StripeInvoiceId>());
export const stripePaymentIntentIdParser = z
  .string()
  .startsWith(STRIPE_PAYMENT_INTENT_PREFIX)
  .transform(cast<StripePaymentIntentId>());

export const stripePayoutIdParser = z.string().startsWith(STRIPE_PAYOUT_PREFIX).transform(cast<StripeTransferId>());
export const stripeSubscriptionIdParser = z
  .string()
  .startsWith(STRIPE_SUBSCRIPTION_PREFIX)
  .transform(cast<StripeSubscriptionId>());
export const stripePriceIdParser = z
  .string()
  .startsWith(STRIPE_PRICE_PREFIX)
  .superRefine((s, ctx) => {
    const channelId = getChannelIdFromPriceId(s as StripePriceId);
    if (!channelId || !isChannelId(channelId)) {
      ctx.addIssue({
        code: 'custom',
        message: "Can't find a valid channel id in provided price id",
      });
    }
  })
  .transform(cast<StripePriceId>());
export const stripeConnectAccountIdParser = z
  .string()
  .startsWith(STRIPE_CONNECT_ACCOUNT_PREFIX)
  .transform(cast<StripeConnectClientId>());

export const stripeConnectTransferIdParser = z
  .string()
  .startsWith(STRIPE_CONNECT_TRANSFER_PREFIX)
  .transform(cast<StripeConnectTransferId>());
export const stripeConnectTransferReversalIdParser = z
  .string()
  .startsWith(STRIPE_CONNECT_TRANSFER_REVERSAL_PREFIX)
  .transform(cast<StripeConnectTransferReversalId>());
export const stripeConnectClientIdParser = z
  .string()
  .startsWith(STRIPE_CONNECT_CLIENT_PREFIX)
  .transform(cast<StripeConnectClientId>());

export const stripeAddressParser = z.object({
  city: z.string().nullable(),
  country: z.string().nullable(),
  line1: z.string().nullable(),
  line2: z.string().nullable(),
  postal_code: z.string().nullable(),
  state: z.string().nullable(),
});

export const stripeCardBrandParser = z.string(); // enumeration but we don't care as much yet

// asserted in non-shared code
export const stripeCardFlatParser = z.object({
  brand: stripeCardBrandParser,
  last4: z.string().min(4).max(4),
});

// asserted in non-shared code
export const stripePaymentMethodFlatParser = z.object({
  id: stripePaymentMethodIdParser,
  object: z.literal('payment_method'),
  customer: stripeCustomerIdParser.nullable(),
  billing_details: z.object({
    address: stripeAddressParser.nullable(),
    email: z.string().nullable(),
    name: z.string().nullable(),
    phone: z.string().nullable(),
  }),
  created: timestampParser,
  metadata: z
    .object({
      /*freeform*/
    })
    .nullable(),
  card: stripeCardFlatParser.optional(),
});
